
// \file Camera.h
// --------------------------------------------------------------------------
// (C) Copyright, 2006
// Computer Graphics Group, University of Siegen, Germany
// All Rights Reserved.
//
// This is unpublished proprietary source code.
// The contents of this file may not be disclosed to third parties,
// copied or duplicated in any form, in whole or in part, without the
// prior written permission of the copyright holder.
// --------------------------------------------------------------------------

#ifndef CAMERA_H
#define CAMERA_H

#include <math.h>

//! OpenGL helper class
/** 
 * Camera representation for OpenGL.
 *
 * This class provides the basic functionality for an OpenGL camera placed on 
 * a sphere around a certain point of interest.
 */
class Camera
{
 public:

  //---------------------------------------------------------------------------
  //! \name                     Instantiation
  //! \{
  //---------------------------------------------------------------------------

  //! Constructor
  Camera(double polar=0.0, double azimut=0.0, double distance=1.0);

  //! Destructor
  ~Camera(void);

  //! Setup the camera.
  void setup(void);

  //!\}------------------------------------------------------------------------


  //---------------------------------------------------------------------------
  //! \name                     Data Access
  //! \{
  //---------------------------------------------------------------------------

  //! Set pitch angle.
  void setPolar(double polar);

  //! Set rotation angle
  void setAzimut(double azimut);

  //! Set look at center
  void setLookAt(int i, double pos) { m_lookAt[i] = pos; update(); };
 
  //! Set camera distance.
  void setDistance(double distance);


  //! Get pitch angle.
  double polar(void) { return m_polar; };

  //! Get rotation angle.
  double azimut(void) { return m_azimut; };

  //! Get camera position.
  double position(int i) { return m_position[i]; };
  
  //! Get look at center.
  double lookAt(int i) { return m_lookAt[i]; };
  
  //! Get camera distance.
  double distance(void) { return m_distance; };

  //!\}------------------------------------------------------------------------


 protected:

   //! Update position.
  void update(void);

  double m_polar;         //!< vertical angle
  double m_azimut;        //!< horizontal angle
  double m_distance;      //!< camera distance to viewpoint
  
  double m_position[3];   //!< camera position
  double m_lookAt[3];     //!< viewpoint
};

#endif // CAMERA_H
